contexttools.get_key_signature_mark_attached_to_component
=========================================================

.. autofunction:: abjad.tools.contexttools.get_key_signature_mark_attached_to_component.get_key_signature_mark_attached_to_component
